*
*
@@ -53,7 +53,7 @@ public class ASiCManifestType {
protected ExtensionsListType aSiCManifestExtensions;
/**
- * Gets the value of the sigReference property.
+ * Ruft den Wert der sigReference-Eigenschaft ab.
*
* @return
* possible object is
@@ -65,7 +65,7 @@ public class ASiCManifestType {
}
/**
- * Sets the value of the sigReference property.
+ * Legt den Wert der sigReference-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -82,7 +82,7 @@ public class ASiCManifestType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the dataObjectReference property.
*
*
@@ -106,7 +106,7 @@ public class ASiCManifestType {
}
/**
- * Gets the value of the aSiCManifestExtensions property.
+ * Ruft den Wert der aSiCManifestExtensions-Eigenschaft ab.
*
* @return
* possible object is
@@ -118,7 +118,7 @@ public class ASiCManifestType {
}
/**
- * Sets the value of the aSiCManifestExtensions property.
+ * Legt den Wert der aSiCManifestExtensions-Eigenschaft fest.
*
* @param value
* allowed object is
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DSAKeyValueType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DSAKeyValueType.java
index 57c5748..eee51e6 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DSAKeyValueType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DSAKeyValueType.java
@@ -1,44 +1,44 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
package at.gv.egiz.asic;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlType;
/**
- *
Java class for DSAKeyValueType complex type.
+ *
Java-Klasse für DSAKeyValueType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -71,7 +71,7 @@ public class DSAKeyValueType {
protected byte[] pgenCounter;
/**
- * Gets the value of the p property.
+ * Ruft den Wert der p-Eigenschaft ab.
*
* @return
* possible object is
@@ -82,7 +82,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the p property.
+ * Legt den Wert der p-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -93,7 +93,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the q property.
+ * Ruft den Wert der q-Eigenschaft ab.
*
* @return
* possible object is
@@ -104,7 +104,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the q property.
+ * Legt den Wert der q-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -115,7 +115,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the g property.
+ * Ruft den Wert der g-Eigenschaft ab.
*
* @return
* possible object is
@@ -126,7 +126,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the g property.
+ * Legt den Wert der g-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -137,7 +137,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the y property.
+ * Ruft den Wert der y-Eigenschaft ab.
*
* @return
* possible object is
@@ -148,7 +148,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the y property.
+ * Legt den Wert der y-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -159,7 +159,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the j property.
+ * Ruft den Wert der j-Eigenschaft ab.
*
* @return
* possible object is
@@ -170,7 +170,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the j property.
+ * Legt den Wert der j-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -181,7 +181,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the seed property.
+ * Ruft den Wert der seed-Eigenschaft ab.
*
* @return
* possible object is
@@ -192,7 +192,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the seed property.
+ * Legt den Wert der seed-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -203,7 +203,7 @@ public class DSAKeyValueType {
}
/**
- * Gets the value of the pgenCounter property.
+ * Ruft den Wert der pgenCounter-Eigenschaft ab.
*
* @return
* possible object is
@@ -214,7 +214,7 @@ public class DSAKeyValueType {
}
/**
- * Sets the value of the pgenCounter property.
+ * Legt den Wert der pgenCounter-Eigenschaft fest.
*
* @param value
* allowed object is
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DataObjectReferenceType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DataObjectReferenceType.java
index f6d0399..e793a4b 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DataObjectReferenceType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DataObjectReferenceType.java
@@ -1,41 +1,41 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
package at.gv.egiz.asic;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
/**
- *
Java class for DataObjectReferenceType complex type.
+ *
Java-Klasse für DataObjectReferenceType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -63,7 +63,7 @@ public class DataObjectReferenceType {
protected Boolean rootfile;
/**
- * Gets the value of the digestMethod property.
+ * Ruft den Wert der digestMethod-Eigenschaft ab.
*
* @return
* possible object is
@@ -75,7 +75,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the digestMethod property.
+ * Legt den Wert der digestMethod-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -87,7 +87,7 @@ public class DataObjectReferenceType {
}
/**
- * Gets the value of the digestValue property.
+ * Ruft den Wert der digestValue-Eigenschaft ab.
*
* @return
* possible object is
@@ -98,7 +98,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the digestValue property.
+ * Legt den Wert der digestValue-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -109,7 +109,7 @@ public class DataObjectReferenceType {
}
/**
- * Gets the value of the dataObjectReferenceExtensions property.
+ * Ruft den Wert der dataObjectReferenceExtensions-Eigenschaft ab.
*
* @return
* possible object is
@@ -121,7 +121,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the dataObjectReferenceExtensions property.
+ * Legt den Wert der dataObjectReferenceExtensions-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -133,7 +133,7 @@ public class DataObjectReferenceType {
}
/**
- * Gets the value of the uri property.
+ * Ruft den Wert der uri-Eigenschaft ab.
*
* @return
* possible object is
@@ -145,7 +145,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the uri property.
+ * Legt den Wert der uri-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -157,7 +157,7 @@ public class DataObjectReferenceType {
}
/**
- * Gets the value of the mimeType property.
+ * Ruft den Wert der mimeType-Eigenschaft ab.
*
* @return
* possible object is
@@ -169,7 +169,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the mimeType property.
+ * Legt den Wert der mimeType-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -181,7 +181,7 @@ public class DataObjectReferenceType {
}
/**
- * Gets the value of the rootfile property.
+ * Ruft den Wert der rootfile-Eigenschaft ab.
*
* @return
* possible object is
@@ -193,7 +193,7 @@ public class DataObjectReferenceType {
}
/**
- * Sets the value of the rootfile property.
+ * Legt den Wert der rootfile-Eigenschaft fest.
*
* @param value
* allowed object is
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionType.java
index 551dd5f..8046ac4 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionType.java
@@ -1,32 +1,32 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
package at.gv.egiz.asic;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlType;
/**
- *
Java class for ExtensionType complex type.
+ *
Java-Klasse für ExtensionType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -41,7 +41,7 @@ public class ExtensionType
protected boolean critical;
/**
- * Gets the value of the critical property.
+ * Ruft den Wert der critical-Eigenschaft ab.
*
*/
public boolean isCritical() {
@@ -49,7 +49,7 @@ public class ExtensionType
}
/**
- * Sets the value of the critical property.
+ * Legt den Wert der critical-Eigenschaft fest.
*
*/
public void setCritical(boolean value) {
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectFactory.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectFactory.java
index cc1d90e..9ec231c 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectFactory.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectFactory.java
@@ -1,18 +1,18 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
package at.gv.egiz.asic;
import java.math.BigInteger;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlElementDecl;
-import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlElementDecl;
+import jakarta.xml.bind.annotation.XmlRegistry;
/**
@@ -32,45 +32,45 @@ import javax.xml.namespace.QName;
@XmlRegistry
public class ObjectFactory {
- private final static QName _SPKIData_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SPKIData");
+ private final static QName _ASiCManifest_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "ASiCManifest");
+ private final static QName _SigReference_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "SigReference");
private final static QName _DataObjectReference_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "DataObjectReference");
- private final static QName _KeyInfo_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "KeyInfo");
+ private final static QName _Extension_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "Extension");
private final static QName _XAdESSignatures_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "XAdESSignatures");
+ private final static QName _Signature_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Signature");
private final static QName _SignatureValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureValue");
- private final static QName _ASiCManifest_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "ASiCManifest");
- private final static QName _KeyValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "KeyValue");
+ private final static QName _SignedInfo_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignedInfo");
+ private final static QName _CanonicalizationMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "CanonicalizationMethod");
+ private final static QName _SignatureMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureMethod");
+ private final static QName _Reference_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Reference");
private final static QName _Transforms_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Transforms");
+ private final static QName _Transform_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Transform");
private final static QName _DigestMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "DigestMethod");
- private final static QName _X509Data_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509Data");
- private final static QName _SignatureProperty_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureProperty");
+ private final static QName _DigestValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "DigestValue");
+ private final static QName _KeyInfo_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "KeyInfo");
private final static QName _KeyName_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "KeyName");
- private final static QName _RSAKeyValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "RSAKeyValue");
- private final static QName _Signature_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Signature");
private final static QName _MgmtData_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "MgmtData");
- private final static QName _Extension_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "Extension");
- private final static QName _SignatureMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureMethod");
+ private final static QName _KeyValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "KeyValue");
+ private final static QName _RetrievalMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "RetrievalMethod");
+ private final static QName _X509Data_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509Data");
+ private final static QName _PGPData_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPData");
+ private final static QName _SPKIData_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SPKIData");
private final static QName _Object_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Object");
+ private final static QName _Manifest_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Manifest");
private final static QName _SignatureProperties_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureProperties");
- private final static QName _Transform_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Transform");
- private final static QName _PGPData_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPData");
- private final static QName _Reference_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Reference");
- private final static QName _RetrievalMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "RetrievalMethod");
+ private final static QName _SignatureProperty_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignatureProperty");
private final static QName _DSAKeyValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "DSAKeyValue");
- private final static QName _DigestValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "DigestValue");
- private final static QName _CanonicalizationMethod_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "CanonicalizationMethod");
- private final static QName _SigReference_QNAME = new QName("http://uri.etsi.org/02918/v1.2.1#", "SigReference");
- private final static QName _SignedInfo_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SignedInfo");
- private final static QName _Manifest_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "Manifest");
+ private final static QName _RSAKeyValue_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "RSAKeyValue");
private final static QName _SPKIDataTypeSPKISexp_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "SPKISexp");
+ private final static QName _PGPDataTypePGPKeyID_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPKeyID");
+ private final static QName _PGPDataTypePGPKeyPacket_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPKeyPacket");
private final static QName _X509DataTypeX509IssuerSerial_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509IssuerSerial");
- private final static QName _X509DataTypeX509CRL_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509CRL");
- private final static QName _X509DataTypeX509SubjectName_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509SubjectName");
private final static QName _X509DataTypeX509SKI_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509SKI");
+ private final static QName _X509DataTypeX509SubjectName_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509SubjectName");
private final static QName _X509DataTypeX509Certificate_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509Certificate");
- private final static QName _SignatureMethodTypeHMACOutputLength_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "HMACOutputLength");
+ private final static QName _X509DataTypeX509CRL_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "X509CRL");
private final static QName _TransformTypeXPath_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "XPath");
- private final static QName _PGPDataTypePGPKeyID_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPKeyID");
- private final static QName _PGPDataTypePGPKeyPacket_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "PGPKeyPacket");
+ private final static QName _SignatureMethodTypeHMACOutputLength_QNAME = new QName("http://www.w3.org/2000/09/xmldsig#", "HMACOutputLength");
/**
* Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: at.gv.egiz.asic
@@ -80,11 +80,11 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link ExtensionType }
+ * Create an instance of {@link ASiCManifestType }
*
*/
- public ExtensionType createExtensionType() {
- return new ExtensionType();
+ public ASiCManifestType createASiCManifestType() {
+ return new ASiCManifestType();
}
/**
@@ -96,19 +96,19 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link ASiCManifestType }
+ * Create an instance of {@link DataObjectReferenceType }
*
*/
- public ASiCManifestType createASiCManifestType() {
- return new ASiCManifestType();
+ public DataObjectReferenceType createDataObjectReferenceType() {
+ return new DataObjectReferenceType();
}
/**
- * Create an instance of {@link DataObjectReferenceType }
+ * Create an instance of {@link ExtensionType }
*
*/
- public DataObjectReferenceType createDataObjectReferenceType() {
- return new DataObjectReferenceType();
+ public ExtensionType createExtensionType() {
+ return new ExtensionType();
}
/**
@@ -119,6 +119,14 @@ public class ObjectFactory {
return new XAdESSignaturesType();
}
+ /**
+ * Create an instance of {@link AnyType }
+ *
+ */
+ public AnyType createAnyType() {
+ return new AnyType();
+ }
+
/**
* Create an instance of {@link ExtensionsListType }
*
@@ -128,51 +136,51 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link AnyType }
+ * Create an instance of {@link SignatureType }
*
*/
- public AnyType createAnyType() {
- return new AnyType();
+ public SignatureType createSignatureType() {
+ return new SignatureType();
}
/**
- * Create an instance of {@link PGPDataType }
+ * Create an instance of {@link SignatureValueType }
*
*/
- public PGPDataType createPGPDataType() {
- return new PGPDataType();
+ public SignatureValueType createSignatureValueType() {
+ return new SignatureValueType();
}
/**
- * Create an instance of {@link KeyValueType }
+ * Create an instance of {@link SignedInfoType }
*
*/
- public KeyValueType createKeyValueType() {
- return new KeyValueType();
+ public SignedInfoType createSignedInfoType() {
+ return new SignedInfoType();
}
/**
- * Create an instance of {@link DSAKeyValueType }
+ * Create an instance of {@link CanonicalizationMethodType }
*
*/
- public DSAKeyValueType createDSAKeyValueType() {
- return new DSAKeyValueType();
+ public CanonicalizationMethodType createCanonicalizationMethodType() {
+ return new CanonicalizationMethodType();
}
/**
- * Create an instance of {@link ReferenceType }
+ * Create an instance of {@link SignatureMethodType }
*
*/
- public ReferenceType createReferenceType() {
- return new ReferenceType();
+ public SignatureMethodType createSignatureMethodType() {
+ return new SignatureMethodType();
}
/**
- * Create an instance of {@link RetrievalMethodType }
+ * Create an instance of {@link ReferenceType }
*
*/
- public RetrievalMethodType createRetrievalMethodType() {
- return new RetrievalMethodType();
+ public ReferenceType createReferenceType() {
+ return new ReferenceType();
}
/**
@@ -184,11 +192,11 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link CanonicalizationMethodType }
+ * Create an instance of {@link TransformType }
*
*/
- public CanonicalizationMethodType createCanonicalizationMethodType() {
- return new CanonicalizationMethodType();
+ public TransformType createTransformType() {
+ return new TransformType();
}
/**
@@ -200,43 +208,43 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link ManifestType }
+ * Create an instance of {@link KeyInfoType }
*
*/
- public ManifestType createManifestType() {
- return new ManifestType();
+ public KeyInfoType createKeyInfoType() {
+ return new KeyInfoType();
}
/**
- * Create an instance of {@link SignaturePropertyType }
+ * Create an instance of {@link KeyValueType }
*
*/
- public SignaturePropertyType createSignaturePropertyType() {
- return new SignaturePropertyType();
+ public KeyValueType createKeyValueType() {
+ return new KeyValueType();
}
/**
- * Create an instance of {@link X509DataType }
+ * Create an instance of {@link RetrievalMethodType }
*
*/
- public X509DataType createX509DataType() {
- return new X509DataType();
+ public RetrievalMethodType createRetrievalMethodType() {
+ return new RetrievalMethodType();
}
/**
- * Create an instance of {@link SignedInfoType }
+ * Create an instance of {@link X509DataType }
*
*/
- public SignedInfoType createSignedInfoType() {
- return new SignedInfoType();
+ public X509DataType createX509DataType() {
+ return new X509DataType();
}
/**
- * Create an instance of {@link RSAKeyValueType }
+ * Create an instance of {@link PGPDataType }
*
*/
- public RSAKeyValueType createRSAKeyValueType() {
- return new RSAKeyValueType();
+ public PGPDataType createPGPDataType() {
+ return new PGPDataType();
}
/**
@@ -248,27 +256,19 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link SignatureValueType }
- *
- */
- public SignatureValueType createSignatureValueType() {
- return new SignatureValueType();
- }
-
- /**
- * Create an instance of {@link KeyInfoType }
+ * Create an instance of {@link ObjectType }
*
*/
- public KeyInfoType createKeyInfoType() {
- return new KeyInfoType();
+ public ObjectType createObjectType() {
+ return new ObjectType();
}
/**
- * Create an instance of {@link SignatureType }
+ * Create an instance of {@link ManifestType }
*
*/
- public SignatureType createSignatureType() {
- return new SignatureType();
+ public ManifestType createManifestType() {
+ return new ManifestType();
}
/**
@@ -280,27 +280,27 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link SignatureMethodType }
+ * Create an instance of {@link SignaturePropertyType }
*
*/
- public SignatureMethodType createSignatureMethodType() {
- return new SignatureMethodType();
+ public SignaturePropertyType createSignaturePropertyType() {
+ return new SignaturePropertyType();
}
/**
- * Create an instance of {@link ObjectType }
+ * Create an instance of {@link DSAKeyValueType }
*
*/
- public ObjectType createObjectType() {
- return new ObjectType();
+ public DSAKeyValueType createDSAKeyValueType() {
+ return new DSAKeyValueType();
}
/**
- * Create an instance of {@link TransformType }
+ * Create an instance of {@link RSAKeyValueType }
*
*/
- public TransformType createTransformType() {
- return new TransformType();
+ public RSAKeyValueType createRSAKeyValueType() {
+ return new RSAKeyValueType();
}
/**
@@ -312,17 +312,38 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SPKIDataType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link ASiCManifestType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link ASiCManifestType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SPKIData")
- public JAXBElement createSPKIData(SPKIDataType value) {
- return new JAXBElement(_SPKIData_QNAME, SPKIDataType.class, null, value);
+ @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "ASiCManifest")
+ public JAXBElement createASiCManifest(ASiCManifestType value) {
+ return new JAXBElement(_ASiCManifest_QNAME, ASiCManifestType.class, null, value);
+ }
+
+ /**
+ * Create an instance of {@link JAXBElement }{@code <}{@link SigReferenceType }{@code >}
+ *
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SigReferenceType }{@code >}
+ */
+ @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "SigReference")
+ public JAXBElement createSigReference(SigReferenceType value) {
+ return new JAXBElement(_SigReference_QNAME, SigReferenceType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link DataObjectReferenceType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link DataObjectReferenceType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link DataObjectReferenceType }{@code >}
*/
@XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "DataObjectReference")
public JAXBElement createDataObjectReference(DataObjectReferenceType value) {
@@ -330,17 +351,25 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link KeyInfoType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link ExtensionType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyInfo")
- public JAXBElement createKeyInfo(KeyInfoType value) {
- return new JAXBElement(_KeyInfo_QNAME, KeyInfoType.class, null, value);
+ @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "Extension")
+ public JAXBElement createExtension(ExtensionType value) {
+ return new JAXBElement(_Extension_QNAME, ExtensionType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link XAdESSignaturesType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link XAdESSignaturesType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link XAdESSignaturesType }{@code >}
*/
@XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "XAdESSignatures")
public JAXBElement createXAdESSignatures(XAdESSignaturesType value) {
@@ -348,152 +377,220 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignatureValueType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignatureType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignatureType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureValue")
- public JAXBElement createSignatureValue(SignatureValueType value) {
- return new JAXBElement(_SignatureValue_QNAME, SignatureValueType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Signature")
+ public JAXBElement createSignature(SignatureType value) {
+ return new JAXBElement(_Signature_QNAME, SignatureType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link ASiCManifestType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignatureValueType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignatureValueType }{@code >}
*/
- @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "ASiCManifest")
- public JAXBElement createASiCManifest(ASiCManifestType value) {
- return new JAXBElement(_ASiCManifest_QNAME, ASiCManifestType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureValue")
+ public JAXBElement createSignatureValue(SignatureValueType value) {
+ return new JAXBElement(_SignatureValue_QNAME, SignatureValueType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link KeyValueType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignedInfoType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignedInfoType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyValue")
- public JAXBElement createKeyValue(KeyValueType value) {
- return new JAXBElement(_KeyValue_QNAME, KeyValueType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignedInfo")
+ public JAXBElement createSignedInfo(SignedInfoType value) {
+ return new JAXBElement(_SignedInfo_QNAME, SignedInfoType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link TransformsType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link CanonicalizationMethodType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link CanonicalizationMethodType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Transforms")
- public JAXBElement createTransforms(TransformsType value) {
- return new JAXBElement(_Transforms_QNAME, TransformsType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "CanonicalizationMethod")
+ public JAXBElement createCanonicalizationMethod(CanonicalizationMethodType value) {
+ return new JAXBElement(_CanonicalizationMethod_QNAME, CanonicalizationMethodType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link DigestMethodType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignatureMethodType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignatureMethodType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DigestMethod")
- public JAXBElement createDigestMethod(DigestMethodType value) {
- return new JAXBElement(_DigestMethod_QNAME, DigestMethodType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureMethod")
+ public JAXBElement createSignatureMethod(SignatureMethodType value) {
+ return new JAXBElement(_SignatureMethod_QNAME, SignatureMethodType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link X509DataType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link ReferenceType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link ReferenceType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509Data")
- public JAXBElement createX509Data(X509DataType value) {
- return new JAXBElement(_X509Data_QNAME, X509DataType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Reference")
+ public JAXBElement createReference(ReferenceType value) {
+ return new JAXBElement(_Reference_QNAME, ReferenceType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignaturePropertyType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link TransformsType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link TransformsType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureProperty")
- public JAXBElement createSignatureProperty(SignaturePropertyType value) {
- return new JAXBElement(_SignatureProperty_QNAME, SignaturePropertyType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Transforms")
+ public JAXBElement createTransforms(TransformsType value) {
+ return new JAXBElement(_Transforms_QNAME, TransformsType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link TransformType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link TransformType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyName")
- public JAXBElement createKeyName(String value) {
- return new JAXBElement(_KeyName_QNAME, String.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Transform")
+ public JAXBElement createTransform(TransformType value) {
+ return new JAXBElement(_Transform_QNAME, TransformType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link DigestMethodType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link DigestMethodType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "RSAKeyValue")
- public JAXBElement createRSAKeyValue(RSAKeyValueType value) {
- return new JAXBElement(_RSAKeyValue_QNAME, RSAKeyValueType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DigestMethod")
+ public JAXBElement createDigestMethod(DigestMethodType value) {
+ return new JAXBElement(_DigestMethod_QNAME, DigestMethodType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignatureType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Signature")
- public JAXBElement createSignature(SignatureType value) {
- return new JAXBElement(_Signature_QNAME, SignatureType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DigestValue")
+ public JAXBElement createDigestValue(byte[] value) {
+ return new JAXBElement(_DigestValue_QNAME, byte[].class, null, ((byte[]) value));
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link KeyInfoType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link KeyInfoType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "MgmtData")
- public JAXBElement createMgmtData(String value) {
- return new JAXBElement(_MgmtData_QNAME, String.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyInfo")
+ public JAXBElement createKeyInfo(KeyInfoType value) {
+ return new JAXBElement(_KeyInfo_QNAME, KeyInfoType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*/
- @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "Extension")
- public JAXBElement createExtension(ExtensionType value) {
- return new JAXBElement(_Extension_QNAME, ExtensionType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyName")
+ public JAXBElement createKeyName(String value) {
+ return new JAXBElement(_KeyName_QNAME, String.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignatureMethodType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureMethod")
- public JAXBElement createSignatureMethod(SignatureMethodType value) {
- return new JAXBElement(_SignatureMethod_QNAME, SignatureMethodType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "MgmtData")
+ public JAXBElement createMgmtData(String value) {
+ return new JAXBElement(_MgmtData_QNAME, String.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link ObjectType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link KeyValueType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link KeyValueType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Object")
- public JAXBElement createObject(ObjectType value) {
- return new JAXBElement(_Object_QNAME, ObjectType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "KeyValue")
+ public JAXBElement createKeyValue(KeyValueType value) {
+ return new JAXBElement(_KeyValue_QNAME, KeyValueType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignaturePropertiesType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link RetrievalMethodType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link RetrievalMethodType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureProperties")
- public JAXBElement createSignatureProperties(SignaturePropertiesType value) {
- return new JAXBElement(_SignatureProperties_QNAME, SignaturePropertiesType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "RetrievalMethod")
+ public JAXBElement createRetrievalMethod(RetrievalMethodType value) {
+ return new JAXBElement(_RetrievalMethod_QNAME, RetrievalMethodType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link TransformType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link X509DataType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link X509DataType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Transform")
- public JAXBElement createTransform(TransformType value) {
- return new JAXBElement(_Transform_QNAME, TransformType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509Data")
+ public JAXBElement createX509Data(X509DataType value) {
+ return new JAXBElement(_X509Data_QNAME, X509DataType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link PGPDataType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link PGPDataType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link PGPDataType }{@code >}
*/
@XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "PGPData")
public JAXBElement createPGPData(PGPDataType value) {
@@ -501,80 +598,103 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link ReferenceType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SPKIDataType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SPKIDataType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Reference")
- public JAXBElement createReference(ReferenceType value) {
- return new JAXBElement(_Reference_QNAME, ReferenceType.class, null, value);
- }
-
- /**
- * Create an instance of {@link JAXBElement }{@code <}{@link RetrievalMethodType }{@code >}}
- *
- */
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "RetrievalMethod")
- public JAXBElement createRetrievalMethod(RetrievalMethodType value) {
- return new JAXBElement(_RetrievalMethod_QNAME, RetrievalMethodType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SPKIData")
+ public JAXBElement createSPKIData(SPKIDataType value) {
+ return new JAXBElement(_SPKIData_QNAME, SPKIDataType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link DSAKeyValueType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link ObjectType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link ObjectType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DSAKeyValue")
- public JAXBElement createDSAKeyValue(DSAKeyValueType value) {
- return new JAXBElement(_DSAKeyValue_QNAME, DSAKeyValueType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Object")
+ public JAXBElement createObject(ObjectType value) {
+ return new JAXBElement(_Object_QNAME, ObjectType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link ManifestType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link ManifestType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DigestValue")
- public JAXBElement createDigestValue(byte[] value) {
- return new JAXBElement(_DigestValue_QNAME, byte[].class, null, ((byte[]) value));
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Manifest")
+ public JAXBElement createManifest(ManifestType value) {
+ return new JAXBElement(_Manifest_QNAME, ManifestType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link CanonicalizationMethodType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignaturePropertiesType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignaturePropertiesType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "CanonicalizationMethod")
- public JAXBElement createCanonicalizationMethod(CanonicalizationMethodType value) {
- return new JAXBElement(_CanonicalizationMethod_QNAME, CanonicalizationMethodType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureProperties")
+ public JAXBElement createSignatureProperties(SignaturePropertiesType value) {
+ return new JAXBElement(_SignatureProperties_QNAME, SignaturePropertiesType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SigReferenceType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link SignaturePropertyType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link SignaturePropertyType }{@code >}
*/
- @XmlElementDecl(namespace = "http://uri.etsi.org/02918/v1.2.1#", name = "SigReference")
- public JAXBElement createSigReference(SigReferenceType value) {
- return new JAXBElement(_SigReference_QNAME, SigReferenceType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignatureProperty")
+ public JAXBElement createSignatureProperty(SignaturePropertyType value) {
+ return new JAXBElement(_SignatureProperty_QNAME, SignaturePropertyType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link SignedInfoType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link DSAKeyValueType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link DSAKeyValueType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SignedInfo")
- public JAXBElement createSignedInfo(SignedInfoType value) {
- return new JAXBElement(_SignedInfo_QNAME, SignedInfoType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "DSAKeyValue")
+ public JAXBElement createDSAKeyValue(DSAKeyValueType value) {
+ return new JAXBElement(_DSAKeyValue_QNAME, DSAKeyValueType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link ManifestType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "Manifest")
- public JAXBElement createManifest(ManifestType value) {
- return new JAXBElement(_Manifest_QNAME, ManifestType.class, null, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "RSAKeyValue")
+ public JAXBElement createRSAKeyValue(RSAKeyValueType value) {
+ return new JAXBElement(_RSAKeyValue_QNAME, RSAKeyValueType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
@XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "SPKISexp", scope = SPKIDataType.class)
public JAXBElement createSPKIDataTypeSPKISexp(byte[] value) {
@@ -582,35 +702,51 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link X509IssuerSerialType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509IssuerSerial", scope = X509DataType.class)
- public JAXBElement createX509DataTypeX509IssuerSerial(X509IssuerSerialType value) {
- return new JAXBElement(_X509DataTypeX509IssuerSerial_QNAME, X509IssuerSerialType.class, X509DataType.class, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "PGPKeyID", scope = PGPDataType.class)
+ public JAXBElement createPGPDataTypePGPKeyID(byte[] value) {
+ return new JAXBElement(_PGPDataTypePGPKeyID_QNAME, byte[].class, PGPDataType.class, ((byte[]) value));
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509CRL", scope = X509DataType.class)
- public JAXBElement createX509DataTypeX509CRL(byte[] value) {
- return new JAXBElement(_X509DataTypeX509CRL_QNAME, byte[].class, X509DataType.class, ((byte[]) value));
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "PGPKeyPacket", scope = PGPDataType.class)
+ public JAXBElement createPGPDataTypePGPKeyPacket(byte[] value) {
+ return new JAXBElement(_PGPDataTypePGPKeyPacket_QNAME, byte[].class, PGPDataType.class, ((byte[]) value));
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link X509IssuerSerialType }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link X509IssuerSerialType }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509SubjectName", scope = X509DataType.class)
- public JAXBElement createX509DataTypeX509SubjectName(String value) {
- return new JAXBElement(_X509DataTypeX509SubjectName_QNAME, String.class, X509DataType.class, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509IssuerSerial", scope = X509DataType.class)
+ public JAXBElement createX509DataTypeX509IssuerSerial(X509IssuerSerialType value) {
+ return new JAXBElement(_X509DataTypeX509IssuerSerial_QNAME, X509IssuerSerialType.class, X509DataType.class, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
@XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509SKI", scope = X509DataType.class)
public JAXBElement createX509DataTypeX509SKI(byte[] value) {
@@ -618,8 +754,25 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
+ */
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509SubjectName", scope = X509DataType.class)
+ public JAXBElement createX509DataTypeX509SubjectName(String value) {
+ return new JAXBElement(_X509DataTypeX509SubjectName_QNAME, String.class, X509DataType.class, value);
+ }
+
+ /**
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
+ *
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
@XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509Certificate", scope = X509DataType.class)
public JAXBElement createX509DataTypeX509Certificate(byte[] value) {
@@ -627,17 +780,25 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link BigInteger }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "HMACOutputLength", scope = SignatureMethodType.class)
- public JAXBElement createSignatureMethodTypeHMACOutputLength(BigInteger value) {
- return new JAXBElement(_SignatureMethodTypeHMACOutputLength_QNAME, BigInteger.class, SignatureMethodType.class, value);
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "X509CRL", scope = X509DataType.class)
+ public JAXBElement createX509DataTypeX509CRL(byte[] value) {
+ return new JAXBElement(_X509DataTypeX509CRL_QNAME, byte[].class, X509DataType.class, ((byte[]) value));
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
*/
@XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "XPath", scope = TransformType.class)
public JAXBElement createTransformTypeXPath(String value) {
@@ -645,21 +806,16 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
- *
- */
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "PGPKeyID", scope = PGPDataType.class)
- public JAXBElement createPGPDataTypePGPKeyID(byte[] value) {
- return new JAXBElement(_PGPDataTypePGPKeyID_QNAME, byte[].class, PGPDataType.class, ((byte[]) value));
- }
-
- /**
- * Create an instance of {@link JAXBElement }{@code <}{@link byte[]}{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link BigInteger }{@code >}
*
+ * @param value
+ * Java instance representing xml element's value.
+ * @return
+ * the new instance of {@link JAXBElement }{@code <}{@link BigInteger }{@code >}
*/
- @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "PGPKeyPacket", scope = PGPDataType.class)
- public JAXBElement createPGPDataTypePGPKeyPacket(byte[] value) {
- return new JAXBElement(_PGPDataTypePGPKeyPacket_QNAME, byte[].class, PGPDataType.class, ((byte[]) value));
+ @XmlElementDecl(namespace = "http://www.w3.org/2000/09/xmldsig#", name = "HMACOutputLength", scope = SignatureMethodType.class)
+ public JAXBElement createSignatureMethodTypeHMACOutputLength(BigInteger value) {
+ return new JAXBElement(_SignatureMethodTypeHMACOutputLength_QNAME, BigInteger.class, SignatureMethodType.class, value);
}
}
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/PGPDataType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/PGPDataType.java
index 1adcf33..1b62f1c 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/PGPDataType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/PGPDataType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,39 +10,39 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlElementRef;
-import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlElementRef;
+import jakarta.xml.bind.annotation.XmlElementRefs;
+import jakarta.xml.bind.annotation.XmlType;
import org.w3c.dom.Element;
/**
- *
Java class for PGPDataType complex type.
+ *
Java-Klasse für PGPDataType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/AnyType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/AnyType.java
index 5c96005..b81ea9b 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/AnyType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/AnyType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,30 +10,30 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSeeAlso;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSeeAlso;
+import jakarta.xml.bind.annotation.XmlType;
import org.w3c.dom.Element;
/**
- *
Java class for AnyType complex type.
+ *
Java-Klasse für AnyType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -69,9 +69,9 @@ public class AnyType {
*
*
* Objects of the following type(s) are allowed in the list
+ * {@link Object }
* {@link String }
* {@link Element }
- * {@link Object }
*
*
*/
@@ -10,30 +10,30 @@ package at.gv.egiz.asic;
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/CanonicalizationMethodType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/CanonicalizationMethodType.java
index 721ba32..e9300cb 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/CanonicalizationMethodType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/CanonicalizationMethodType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,31 +10,31 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
/**
- *
Java class for CanonicalizationMethodType complex type.
+ *
Java-Klasse für CanonicalizationMethodType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -58,7 +58,7 @@ public class CanonicalizationMethodType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -70,8 +70,8 @@ public class CanonicalizationMethodType {
*
*
* Objects of the following type(s) are allowed in the list
- * {@link String }
* {@link Object }
+ * {@link String }
*
*
*/
@@ -83,7 +83,7 @@ public class CanonicalizationMethodType {
}
/**
- * Gets the value of the algorithm property.
+ * Ruft den Wert der algorithm-Eigenschaft ab.
*
* @return
* possible object is
@@ -95,7 +95,7 @@ public class CanonicalizationMethodType {
}
/**
- * Sets the value of the algorithm property.
+ * Legt den Wert der algorithm-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -58,7 +58,7 @@ public class CanonicalizationMethodType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DigestMethodType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DigestMethodType.java
index bfa4f8d..a4f0e13 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DigestMethodType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/DigestMethodType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,32 +10,32 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
import org.w3c.dom.Element;
/**
- *
Java class for DigestMethodType complex type.
+ *
Java-Klasse für DigestMethodType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -59,7 +59,7 @@ public class DigestMethodType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -71,9 +71,9 @@ public class DigestMethodType {
*
*
* Objects of the following type(s) are allowed in the list
+ * {@link Object }
* {@link String }
* {@link Element }
- * {@link Object }
*
*
*/
@@ -85,7 +85,7 @@ public class DigestMethodType {
}
/**
- * Gets the value of the algorithm property.
+ * Ruft den Wert der algorithm-Eigenschaft ab.
*
* @return
* possible object is
@@ -97,7 +97,7 @@ public class DigestMethodType {
}
/**
- * Sets the value of the algorithm property.
+ * Legt den Wert der algorithm-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -59,7 +59,7 @@ public class DigestMethodType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionsListType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionsListType.java
index 8d841fb..63a85d2 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionsListType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ExtensionsListType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,27 +10,27 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlType;
/**
- *
Java class for ExtensionsListType complex type.
+ *
Java-Klasse für ExtensionsListType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -50,7 +50,7 @@ public class ExtensionsListType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the extension property.
*
*
@@ -50,7 +50,7 @@ public class ExtensionsListType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the extension property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyInfoType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyInfoType.java
index f750cdd..0036ba5 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyInfoType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyInfoType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,45 +10,45 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlElementRef;
-import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlElementRef;
+import jakarta.xml.bind.annotation.XmlElementRefs;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.w3c.dom.Element;
/**
- *
Java class for KeyInfoType complex type.
+ *
Java-Klasse für KeyInfoType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -95,16 +95,16 @@ public class KeyInfoType {
*
*
* Objects of the following type(s) are allowed in the list
- * {@link JAXBElement }{@code <}{@link String }{@code >}
+ * {@link JAXBElement }{@code <}{@link KeyValueType }{@code >}
* {@link JAXBElement }{@code <}{@link PGPDataType }{@code >}
- * {@link String }
* {@link JAXBElement }{@code <}{@link RetrievalMethodType }{@code >}
- * {@link JAXBElement }{@code <}{@link String }{@code >}
* {@link JAXBElement }{@code <}{@link SPKIDataType }{@code >}
- * {@link Element }
- * {@link JAXBElement }{@code <}{@link KeyValueType }{@code >}
* {@link JAXBElement }{@code <}{@link X509DataType }{@code >}
+ * {@link JAXBElement }{@code <}{@link String }{@code >}
+ * {@link JAXBElement }{@code <}{@link String }{@code >}
* {@link Object }
+ * {@link String }
+ * {@link Element }
*
*
*/
@@ -116,7 +116,7 @@ public class KeyInfoType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -128,7 +128,7 @@ public class KeyInfoType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -10,45 +10,45 @@ package at.gv.egiz.asic;
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
index e6fee6f..3f6af21 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,34 +10,34 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlElementRef;
-import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlElementRef;
+import jakarta.xml.bind.annotation.XmlElementRefs;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlType;
import org.w3c.dom.Element;
/**
- *
Java class for KeyValueType complex type.
+ *
Java-Klasse für KeyValueType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -49,8 +49,8 @@ import org.w3c.dom.Element;
public class KeyValueType {
@XmlElementRefs({
- @XmlElementRef(name = "RSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false),
- @XmlElementRef(name = "DSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false)
+ @XmlElementRef(name = "DSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false),
+ @XmlElementRef(name = "RSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false)
})
@XmlMixed
@XmlAnyElement(lax = true)
@@ -62,7 +62,7 @@ public class KeyValueType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -74,11 +74,11 @@ public class KeyValueType {
*
*
* Objects of the following type(s) are allowed in the list
- * {@link String }
- * {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
* {@link JAXBElement }{@code <}{@link DSAKeyValueType }{@code >}
- * {@link Element }
+ * {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
* {@link Object }
+ * {@link String }
+ * {@link Element }
*
*
*/
@@ -62,7 +62,7 @@ public class KeyValueType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ManifestType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ManifestType.java
index 2c14726..9c0b032 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ManifestType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ManifestType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,33 +10,33 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
/**
- *
Java class for ManifestType complex type.
+ *
Java-Klasse für ManifestType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
*
*
@@ -61,7 +61,7 @@ public class ManifestType {
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the reference property.
*
*
@@ -85,7 +85,7 @@ public class ManifestType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -97,7 +97,7 @@ public class ManifestType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -61,7 +61,7 @@ public class ManifestType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the reference property.
*
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectType.java
index 813c6d7..6ad2439 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/ObjectType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See http://java.sun.com/xml/jaxb
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,37 +10,37 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.w3c.dom.Element;
/**
- *
Java class for ObjectType complex type.
+ *
Java-Klasse für ObjectType complex type.
*
- *
The following schema fragment specifies the expected content contained within this class.
+ *
Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
*
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a set method for the content property.
*
*
@@ -83,9 +83,9 @@ public class ObjectType {
*
*
* Objects of the following type(s) are allowed in the list
+ * {@link Object }
* {@link String }
* {@link Element }
- * {@link Object }
*
*
*/
@@ -97,7 +97,7 @@ public class ObjectType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -109,7 +109,7 @@ public class ObjectType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -121,7 +121,7 @@ public class ObjectType {
}
/**
- * Gets the value of the mimeType property.
+ * Ruft den Wert der mimeType-Eigenschaft ab.
*
* @return
* possible object is
@@ -133,7 +133,7 @@ public class ObjectType {
}
/**
- * Sets the value of the mimeType property.
+ * Legt den Wert der mimeType-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -145,7 +145,7 @@ public class ObjectType {
}
/**
- * Gets the value of the encoding property.
+ * Ruft den Wert der encoding-Eigenschaft ab.
*
* @return
* possible object is
@@ -157,7 +157,7 @@ public class ObjectType {
}
/**
- * Sets the value of the encoding property.
+ * Legt den Wert der encoding-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -10,37 +10,37 @@ package at.gv.egiz.asic;
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a set method for the content property.
*